@@ -5,11 +5,10 @@ import numpy as np
 
 drum_names_to_pitches = {
     'bass_drum': [35, 36],
-    'closed_hihat': [42],
+    'closed_hihat': [42, 44],
     'crash': [49, 57],
     'floor_tom': [41, 43],
     'open_hihat': [46],
-    'pedal_hihat': [44],
     'ride': [51, 59],
     'snare': [38, 39, 40],
     'tambourine': [54],
